import 'package:equatable/equatable.dart';

class ApiConfig extends Equatable {
  final bool encrypt;
  final String url;
  final String? publicKey;
  final String? secretKey;
  final Duration defaultTimeout;
  final Duration uploadTimeout;
  final String publicVersion;
  final String privateVersion;
  final bool debugMode;
  Map<String, dynamic>? defaultParameters;

  ApiConfig(
    this.url,
    this.publicVersion,
    this.privateVersion, {
    this.publicKey,
    this.secretKey,
    this.encrypt = false,
    this.defaultParameters,
    this.debugMode = false,
    this.defaultTimeout = const Duration(seconds: 60),
    this.uploadTimeout = const Duration(minutes: 5),
  })  : assert(encrypt == false ||
            (encrypt && publicKey != null && secretKey != null)) {
    if (defaultParameters == null) {
      defaultParameters = {};
    }
  }

  @override
  String toString() {
    return {
      'url': url,
      'encrypt': encrypt,
      'debugMode': debugMode,
      'publicKey': publicKey,
      'secretKey': secretKey,
      'defaultParameters': defaultParameters,
      'defaultTimeout': defaultTimeout.toString(),
      'uploadTimeout': uploadTimeout.toString(),
    }.toString();
  }

  @override
  List<Object?> get props => [
    url,
    encrypt,
    publicKey,
    secretKey,
    defaultTimeout,
    uploadTimeout
  ];
}
